<?php
/**
 * Created by PhpStorm.
 * User: konstantin
 * Date: 1/29/18
 * Time: 3:18 PM
 */

class ActionCreate extends CAction
{

    /**
     * Create new partner action
     */
    public function run($widget)
    {

        $widget->controller->pageTitle = $widget->pluginName . ' • New partner';

        /**
         * Defaults, nTransit legacy
         */
        $model = new PartnerForm;
        $model->to_partner = 'to_partner';
        $model->from_partner = 'from_partner';
        $model->volume = $widget->volume;

        $result = null;
        $partnerSaved = false;
        if (isset($_POST['PartnerForm'])) {

            $model->attributes = $_POST['PartnerForm'];

            if (isset($_POST['step'])) {
                switch ($_POST['step']) {
                    case 'partner':
                        $error = false;

                        // validate user input and redirect to the previous page if valid
                        if ($model->validate()) {
                            /**
                             * Save partner
                             */
                            $partner = Partner::model()->findByAttributes(array('name' => $model->name));
                            if (!$partner) {
                                $partner = new Partner();
                                $partner->attributes = $model->attributes;

                                /**
                                 * NOTE: suffix is a legacy field, required for dB consistency
                                 */
                                $partner->suffix = 'nt';
                                $saved = false;

                                try {
                                    $saved = $partner->save();
                                } catch (Exception $exception) {
                                }

                                if (!$saved) {
                                    $error = true;
                                    $result = NtransitHelper::getStatus(' Can\'t create Partner database record ' .
                                        (isset($partner->errors) ? print_r($partner->errors, true) : '') . ' ' .
                                        print_r($exception->getMessage(), true), true);
                                } else {
                                    $result = NtransitHelper::getStatus('Partner database record created <a id="update-url" class="hidden" href="'
                                        . Yii::app()->createUrl('admin/plugin/nTransitPlugin') . '?' .
                                        http_build_query(array('action' => 'update', 'id' => $partner->id)) . '"></a>');
                                }

                            } else {
                                $result = NtransitHelper::getStatus($model->name .
                                    ' partner database record already exists, continue <a id="update-url" class="hidden" href="'
                                    . Yii::app()->createUrl('admin/plugin/nTransitPlugin') . '?' .
                                    http_build_query(array('action' => 'update', 'id' => $partner->id)) . '"></a>');
                            }

                        } else {
                            $error = true;
                            $result = $model->getErrors();
                        }

                        echo json_encode(array('result' => $result, 'error' => $error));

                        Yii::app()->end();
                        break;

                    case 'partner_folder':
                        NtransitHelper::createPartnerFolder($model->volume, $model->name, $widget);
                        break;

                    case 'to_partner':
                        NtransitHelper::createPartnerFolder($model->volume . DIRECTORY_SEPARATOR . $model->name,
                            $model->to_partner, $widget);
                        break;

                    case 'from_partner':
                        NtransitHelper::createPartnerFolder($model->volume . DIRECTORY_SEPARATOR . $model->name,
                            $model->from_partner, $widget);
                        break;

                    case 'trigger_new_file':
                        if (NtransitHelper::createTrigger(NtransitHelper::EVENT_NEW_FILE_LABEL, $widget)) {
                            NtransitHelper::addTriggerEvent(NtransitHelper::EVENT_NEW_FILE, 
                                NtransitHelper::EVENT_NEW_FILE_LABEL, $widget);
                            NtransitHelper::addTriggerFolder($model->volume, NtransitHelper::EVENT_NEW_FILE_LABEL, $widget);
                            echo json_encode(array('error' => false,
                                'result' => NtransitHelper::getStatus("Trigger " . NtransitHelper::EVENT_NEW_FILE_LABEL
                                    . " created")));
                        } else {
                            echo json_encode(array('error' => false,
                                'result' => NtransitHelper::getStatus("Trigger New File already created, continue")));
                        }
                        Yii::app()->end();
                        break;

                    case 'trigger_move_into':
                        if (NtransitHelper::createTrigger(NtransitHelper::EVENT_MOVE_INTO_LABEL, $widget)) {
                            NtransitHelper::addTriggerEvent(NtransitHelper::EVENT_MOVE_INTO, 
                                NtransitHelper::EVENT_MOVE_INTO_LABEL, $widget);
                            NtransitHelper::addTriggerFolder($model->volume, NtransitHelper::EVENT_MOVE_INTO_LABEL, $widget);
                            echo json_encode(array('error' => false,
                                'result' => NtransitHelper::getStatus("Trigger " . NtransitHelper::EVENT_MOVE_INTO_LABEL
                                    . " created")));
                        } else {
                            echo json_encode(array('error' => false,
                                'result' => NtransitHelper::getStatus("Trigger " . NtransitHelper::EVENT_MOVE_INTO_LABEL
                                    . " already created, continue")));
                        }
                        Yii::app()->end();
                        break;


                    case 'trigger_download_hi':
                        if (NtransitHelper::createTrigger(NtransitHelper::EVENT_DOWNLOAD_HIRES_LABEL, $widget)) {
                            NtransitHelper::addTriggerEvent(NtransitHelper::EVENT_DOWNLOAD_HIRES, 
                                NtransitHelper::EVENT_DOWNLOAD_HIRES_LABEL, $widget);
                            NtransitHelper::addTriggerFolder($model->volume, NtransitHelper::EVENT_DOWNLOAD_HIRES_LABEL, $widget);
                            echo json_encode(array('error' => false,
                                'result' => NtransitHelper::getStatus("Trigger " . NtransitHelper::EVENT_DOWNLOAD_HIRES_LABEL
                                    . " created")));
                        } else {
                            echo json_encode(array('error' => false,
                                'result' => NtransitHelper::getStatus("Trigger " . NtransitHelper::EVENT_DOWNLOAD_HIRES_LABEL
                                    . " already created, continue")));
                        }
                        Yii::app()->end();
                        break;

                    case 'trigger_download_fpo':
                        if (NtransitHelper::createTrigger(NtransitHelper::EVENT_DOWNLOAD_FPO_LABEL, $widget)) {
                            NtransitHelper::addTriggerEvent(NtransitHelper::EVENT_DOWNLOAD_FPO, 
                                NtransitHelper::EVENT_DOWNLOAD_FPO_LABEL, $widget);
                            NtransitHelper::addTriggerFolder($model->volume, NtransitHelper::EVENT_DOWNLOAD_FPO_LABEL, $widget);
                            echo json_encode(array('error' => false,
                                'result' => NtransitHelper::getStatus("Trigger " . NtransitHelper::EVENT_DOWNLOAD_FPO_LABEL
                                    . " created")));
                        } else {
                            echo json_encode(array('error' => false,
                                'result' => NtransitHelper::getStatus("Trigger " . NtransitHelper::EVENT_DOWNLOAD_FPO_LABEL
                                    . " already created, continue")));
                        }
                        Yii::app()->end();
                        break;

                    case 'trigger_image_order':
                        if (NtransitHelper::createTrigger(NtransitHelper::EVENT_IMAGE_ORDER_LABEL, $widget)) {
                            NtransitHelper::addTriggerEvent(NtransitHelper::EVENT_IMAGE_ORDER, 
                                NtransitHelper::EVENT_IMAGE_ORDER_LABEL, $widget);
                            NtransitHelper::addTriggerFolder($model->volume, NtransitHelper::EVENT_IMAGE_ORDER_LABEL, $widget);
                            echo json_encode(array('error' => false,
                                'result' => NtransitHelper::getStatus("Trigger " . NtransitHelper::EVENT_IMAGE_ORDER_LABEL
                                    . " created")));
                        } else {
                            echo json_encode(array('error' => false,
                                'result' => NtransitHelper::getStatus("Trigger " . NtransitHelper::EVENT_IMAGE_ORDER_LABEL .
                                    " already created, continue")));
                        }
                        Yii::app()->end();
                        break;

                    case 'trigger_image_preview':
                        if (NtransitHelper::createTrigger(NtransitHelper::EVENT_IMAGE_PREVIEW_LABEL, $widget)) {
                            NtransitHelper::addTriggerEvent(NtransitHelper::EVENT_IMAGE_PREVIEW, 
                                NtransitHelper::EVENT_IMAGE_PREVIEW_LABEL, $widget);
                            NtransitHelper::addTriggerFolder($model->volume, NtransitHelper::EVENT_IMAGE_PREVIEW_LABEL, $widget);
                            echo json_encode(array('error' => false,
                                'result' => NtransitHelper::getStatus("Trigger " . NtransitHelper::EVENT_IMAGE_PREVIEW_LABEL
                                    . " created")));
                        } else {
                            echo json_encode(array('error' => false,
                                'result' => NtransitHelper::getStatus("Trigger " . NtransitHelper::EVENT_IMAGE_PREVIEW_LABEL .
                                    " already created, continue")));
                        }
                        Yii::app()->end();
                        break;

                    case 'trigger_date_expired':
                        if (NtransitHelper::createTrigger(NtransitHelper::EVENT_DATE_EXPIRED_LABEL, $widget)) {
                            NtransitHelper::addTriggerEvent(NtransitHelper::EVENT_DATE_EXPIRED, 
                                NtransitHelper::EVENT_DATE_EXPIRED_LABEL, $widget);
                            NtransitHelper::addTriggerFolder($model->volume, NtransitHelper::EVENT_DATE_EXPIRED_LABEL, $widget);
                            echo json_encode(array('error' => false,
                                'result' => NtransitHelper::getStatus("Trigger " . NtransitHelper::EVENT_DATE_EXPIRED_LABEL
                                    . " created")));
                        } else {
                            echo json_encode(array('error' => false,
                                'result' => NtransitHelper::getStatus("Trigger " . NtransitHelper::EVENT_DATE_EXPIRED_LABEL .
                                    " already created, continue")));
                        }
                        Yii::app()->end();
                        break;
                }
            }
        }

        return $widget->render('standalone', array(
            'breadcrumbs' => $widget->render('breadcrumbs', array(
                    'LIST' => NtransitHelper::getBreadcrumbs(array(CHtml::link('Home', 'nTransitPlugin'), 'New partner')))
            ),
            'header' => '<i class="fa fa-address-card" aria-hidden="true"></i> New Partner',
            'imgPath' => $widget->imgFolder,
            'result' => null,
            'content' => $widget->render('create', array(
                'model' => $model,
                'partnerSaved' => $partnerSaved,
                'result' => $result,
            )),
        ));
    }

}