<?php
/**
 * Created by PhpStorm.
 * User: konstantin
 * Date: 1/29/18
 * Time: 3:21 PM
 */

class ActionUpdate extends CAction
{
    /**
     * Default Folder Life Span (Hours), 3 days, based on WN date data field dropdown
     */
    const DEFAULT_FILE_LIFESPAN = 4320;

    /**
     * Update partner action
     */
    public function run($widget)
    {
        $widget->controller->pageTitle = $widget->pluginName . ' • Update partner';

        $id = Yii::app()->request->getParam('id', null);

        if (!$id) {
            throw new Exception('Partner ID is required');
        }

        /**
         * @var $partner Partner
         */
        $partner = Partner::model()->findByPk($id);

        if (!$partner) {
            throw new Exception('Can\'t find partner with ID ' . $id);
        }

        $model = new PartnerFormFull;
        $model->id = $partner->id;
        $model->attributes = $partner->attributes;

        /**
         * Defaults
         */
        $model->deliveryType = 0;
        $model->folderLifespan = self::DEFAULT_FILE_LIFESPAN;
        $model->partnerHasSite = false;
        $model->hires = true;
        $model->preview = true;
        $model->stream = true;
        $model->downloadHiresStream = true;
        $model->downloadPreview = true;

        $model->sentName = 'Partner';
        $model->sentSubject = 'New nTransit Item Sent';
        $model->sentMessage = 'New item sent via nTransit';

        $model->receivedSubject = 'New nTransit Item Received';
        $model->receivedMessage = 'New item received via nTransit';
        $model->receivedName = 'Contact';

        /**
         * Get data from partner config
         */
        if (!empty($partner->config)) {
            $configData = json_decode($partner->config, true);
            if (is_array($configData) && count($configData)) {
                $model->attributes = $configData;
            }
        }

        /**
         * Save updated partner config
         */
        if (isset($_POST['PartnerFormFull'])) {
            $model->attributes = $_POST['PartnerFormFull'];

            CHtml::$errorCss = 'is-invalid';

            if ($model->validate()) {

                $partner->config = json_encode($model->attributes);

                if (!$partner->save()) {
                    throw new Exception('Can\'t save partner config ' .
                        print_r($partner->getErrors(), true));
                } else {
                    $widget->controller->redirect(Yii::app()->createUrl('admin/plugin/nTransitPlugin'));
                }

            }
        }

        return $widget->render('standalone', array(
            'breadcrumbs' => $widget->render('breadcrumbs', array('LIST'=>NtransitHelper::getBreadcrumbs(array(
                CHtml::link('Home', 'nTransitPlugin'),
                $partner->name,
                'Update'
            )))),
            'header' => '<i class="fa fa-address-card" aria-hidden="true"></i> Update Partner: ' . $partner->name,
            'imgPath' => $widget->imgFolder,
            'result' => null,
            'content' => $widget->render('update', array(
                'model' => $model,
            )),
        ));
    }



}