<?php

/**
 * This is the model class for table "Log".
 *
 * @property integer $id
 * @property integer $date
 * @property integer $type
 * @property integer $fileid
 * @property string $message
 * @property string $path
 * @property string $user
 * @property string $partner
 */
class Log extends AActiveRecord
{

    public $fromDate;
    public $toDate;

    /**
     * @return string the associated database table name
     */
    public function tableName()
    {
        return 'log';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('id, date, type, fileid', 'numerical', 'integerOnly'=>true),
            array('message, path, user, partner', 'length', 'max'=>1000000),
            array('id, date, type, partner, message, path, user, fromDate, toDate', 'safe', 'on'=>'search'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels()
    {
        return array(
            'id' => '#',
            'date' => 'Date',
            'type' => 'Event type',
            'fileid' => 'File ID',
            'message' => 'Description',
            'path' => 'File Path',
            'user' => 'User',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search($partialPartner = true)
    {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria=new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('date', $this->date);
        $criteria->compare('type', $this->type);
        $criteria->compare('fileid', $this->fileid);
        $criteria->compare('message', $this->message, true);
        $criteria->compare('path', $this->path, true);
        $criteria->compare('user', $this->user, true);
        $criteria->compare('partner', $this->partner, $partialPartner);

        if(!empty($this->fromDate) && !empty($this->toDate)) {

            $criteria->addCondition("datetime(`date`, 'unixepoch') >= '$this->fromDate' AND datetime(`date`, 'unixepoch') <= '$this->toDate'");

        } elseif(!empty($this->fromDate) && empty($this->toDate)) {

            $criteria->addCondition("datetime(`date`, 'unixepoch') >= '$this->fromDate'");

        } elseif(empty($this->fromDate) && !empty($this->toDate)) {

            $criteria->addCondition("datetime(`date`, 'unixepoch') <= '$this->toDate'");

        }

        return new CActiveDataProvider($this, array(
            'criteria'=>$criteria,
            'sort'=>array(
                'defaultOrder'=>'id DESC',
            )
        ));
    }

    public function formatType() {

        $events = array(
            '8' => 'New File',
            '2097152' => 'Move Into',
            '262144' => 'Download High Res',
            '524288' => 'Download FPO',
            '2048' => 'Image Order',
            '1048576' => 'Preview Viewed',
            '-1' => 'File expired',
        );
        return isset($events[$this->type]) ? $events[$this->type] : 'Unknown';
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Partner the static model class
     */
    public static function model($className=__CLASS__)
    {
        return parent::model($className);
    }

}
