<?php

/**
 * This is the model class for table "Partners".
 *
 * @property integer $id
 * @property string $name
 * @property string $to_partner
 * @property string $from_partner
 * @property string $volume
 * @property integer $created
 * @property integer $updated
 * @property string $creator
 * @property string $updater
 * @property string $config
 *
 */
class Partner extends AActiveRecord
{

    /**
     * @return string the associated database table name
     */
    public function tableName()
    {
        return 'partners';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: suffix is a legacy field, required for dB consistency
        return array(
            array('name, to_partner, from_partner, volume', 'required'),
            array('id, created, updated', 'numerical', 'integerOnly' => true),
            array('config', 'length', 'max'=>1000000),
            array('name, to_partner, from_partner, volume, creator, updater', 'length', 'max' => 255),
            array('id, name, suffix, to_partner, from_partner, volume, created, updated, creator, updater, config',
                'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels()
    {
        return array(
            'id' => '#',
            'name' => 'Name',
            'to_partner' => 'To partner',
            'from_partner' => 'From partner',
            'volume' => 'Volume',
            'created' => 'Created',
            'updated' => 'Updated',
            'creator' => 'Creator',
            'updater' => 'Updater',
            'config' => 'Configuration',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search()
    {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('name', $this->name, true);
        $criteria->compare('to_partner', $this->to_partner, true);
        $criteria->compare('from_partner', $this->from_partner, true);
        $criteria->compare('volume', $this->volume, true);
        $criteria->compare('created', $this->created, true);
        $criteria->compare('updated', $this->updated, true);
        $criteria->compare('creator', $this->creator, true);
        $criteria->compare('updater', $this->updater, true);

        $sortable = array('name', 'to_partner', 'from_partner', 'volume');

        $sort = array();
        foreach ($sortable as $item) {
            $sort[$item] = array(
                'asc' => "$item COLLATE NOCASE ASC",
                'desc' => "$item COLLATE NOCASE DESC"
            );
        }

        $dataProvider = new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'attributes' => $sort,
                'defaultOrder' => array('name' => CSort::SORT_ASC),
            )
        ));
        return $dataProvider;
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Partner the static model class
     */
    public static function model($className = __CLASS__)
    {
        return parent::model($className);
    }

    /**
     * Save created, updated and creator, updater before model save
     * @return mixed
     */
    public function beforeSave()
    {
        if ($this->isNewRecord) {
            $this->created = time();
            $this->creator = Yii::app()->user->name;
        } else {
            $this->updated = time();
            $this->updater = Yii::app()->user->name;
        }

        return parent::beforeSave();

    }

}
