<?php

/**
 * PartnerForm class.
 * PartnerForm is the data structure for keeping
 * partner form data.
 */
class PartnerForm extends CFormModel
{

    public $name;
    public $to_partner;
    public $from_partner;
    public $volume;
    public $created;
    public $updated;
    public $creator;
    public $updater;

    /**
     * Declares the validation rules.
     */
    public function rules()
    {
        return array(
            // name, to_partner, from_partner and volume are required
            array('name, to_partner, from_partner, volume', 'required'),
            array('created, updated, creator, updater', 'safe'),
            array('name, to_partner, from_partner, volume', 'length', 'max' => 255),
            array('volume', 'validateVolume'),
        );
    }

    public function validateVolume($attribute)
    {
        if (empty($this->volume)) return;

        $username = NtransitHelper::getSetting('username');
        $password = NtransitHelper::getSetting('password');

        $portalDI = PortalDI::getInstance();
        $portalDI->setUsername($username);
        $portalDI->setPassword($password);
        $webnative = $portalDI->getHost();

        $exists = false;
        $volumes = $portalDI->callPortal(PortalDI::ACTION_SHOW_VOLUMES);

        foreach ($volumes as $volume) {
            if($volume['path'] === $this->volume) {
                $exists = true;
                break;
            }
        }

        if(!$exists) {
            $this->addError($attribute, "nTransit volume {$this->volume} doesn't exist on webnative {$webnative} 
        or user $username has no access");
        }
    }


    /**
     * Declares customized attribute labels.
     * If not declared here, an attribute would have a label that is
     * the same as its name with the first letter in upper case.
     */
    public function attributeLabels()
    {
        return array(
            'id' => '#',
            'date' => 'Date',
            'name' => 'Name',
            'to_partner' => 'To partner',
            'from_partner' => 'From partner',
        );
    }
}
