<?php

/**
 * PartnerForm class.
 * PartnerForm is the data structure for keeping
 * partner form data.
 */
class PartnerFormFull extends CFormModel
{

    /**
     * General fields
     */
    public $id;
    public $name;
    public $to_partner;
    public $from_partner;
    public $volume;
    public $created;
    public $updated;
    public $creator;
    public $updater;

    /**
     * Config fields
     */
    public $deliveryType;
    public $folderLifespan;
    public $partnerHasSite;
    public $hires;
    public $preview;
    public $stream;

    /**
     * Item sent message fields
     */
    public $sentFrom;
    public $sentName;
    public $sentRecipients;
    public $sentCCRecipients;
    public $sentBCCRecipients;
    public $sentSubject;
    public $sentMessage;

    /**
     * Download Notification Receipts
     */
    public $downloadRecipients;
    public $downloadHiresStream;
    public $downloadPreview;

    /**
     * Item Received Message
     */
    public $receivedFrom;
    public $receivedName;
    public $receivedRecipients;
    public $receivedCCRecipients;
    public $receivedBCCRecipients;
    public $receivedSubject;
    public $receivedMessage;

    public $import;

    /**
     * Declares the validation rules.
     */
    public function rules()
    {
        return array(
            // name, to_partner, from_partner and volume are required
            array('name, to_partner, from_partner, volume, deliveryType, folderLifespan, partnerHasSite, hires, 
            preview, stream, sentName, sentSubject, sentMessage, receivedName, receivedSubject, receivedMessage, 
            downloadHiresStream, downloadPreview', 'required'),

            array('sentFrom, receivedFrom', 'email'),

            array('created, updated, creator, updater, import', 'safe'),

            array('sentRecipients, sentCCRecipients, sentBCCRecipients, downloadRecipients, receivedRecipients,
            receivedCCRecipients, receivedBCCRecipients', 'length', 'max' => 500),

            array('sentRecipients, sentCCRecipients, sentBCCRecipients, downloadRecipients, receivedRecipients,
            receivedCCRecipients, receivedBCCRecipients', 'checkEmailList'),

            array('sentMessage', 'filter', 'filter' => array($object = new CHtmlPurifier(), 'purify')),
        );
    }

    public function checkEmailList($attribute, $params) {

        $validator = new CEmailValidator();

        if(strpos($this->$attribute, ';') !== false) {
            $this->addError($attribute, "Semicolon (;) is not a valid divider for multiple emails, please use comma (,)");
        } else {
            $emailArray = explode(',', $this->$attribute);

            if (is_array($emailArray) && count($emailArray)) {

                foreach ($emailArray as $email) {

                    /**
                     * Validate non empty email/s
                     */
                    if (!empty($email) && !$validator->validateValue(trim($email))) {
                        $this->addError($attribute, "'$email' is not a valid email.");
                    }
                }
            }
        }

    }

    /**
     * Declares customized attribute labels.
     * If not declared here, an attribute would have a label that is
     * the same as its name with the first letter in upper case.
     */
    public function attributeLabels()
    {
        return array(
            'id' => '#',
            'date' => 'Date',
            'name' => 'Name',
            'to_partner' => 'To partner',
            'from_partner' => 'From partner',
            'deliveryType' => 'Handling of Loose Files',
            'folderLifespan' => 'Folder Life Span',
            'partnerHasSite' => 'Use partner name as site name',
            'hires' => 'Download High Resolution',
            'preview' => 'Preview',
            'stream' => 'Stream',

            'sentFrom' => 'From/Reply-to Email',
            'sentName' => 'Main Contact Name',
            'sentRecipients' => 'Recipient Emails',
            'sentCCRecipients' => 'CC Recipient Emails',
            'sentBCCRecipients' => 'BCC Recipient Emails',
            'sentSubject' => 'Subject',
            'sentMessage' => 'Message',

            'downloadRecipients' =>'Download Notification Receipts',
            'downloadHiresStream' => 'Download High Resolution/Stream',
            'downloadPreview' => 'Preview',

            'receivedFrom' => 'From/Reply-to Email',
            'receivedName' => 'Main Contact Name',
            'receivedRecipients' => 'Recipient Emails',
            'receivedCCRecipients' => 'CC Recipient Emails',
            'receivedBCCRecipients' => 'BCC Recipient Emails',
            'receivedSubject' => 'Subject',
            'receivedMessage' => 'Message',

        );
    }
}
