<?php

/**
 * SettingsForm class.
 * SettingsForm is the data structure for keeping
 * settings form data.
 */
class SettingsForm extends CFormModel
{
    public $volume;
    public $actionName;
    public $actionSettings;
    public $folderLifespanKeywordId;
    public $folderLifespanKeyword;
    public $username;
    public $password;

    /**
     * Declares the validation rules.
     */
    public function rules()
    {
        return array(
            array('volume, actionName, actionSettings, folderLifespanKeywordId, folderLifespanKeyword, username, password', 'required'),
            array('username', 'validateUsername'),
            array('folderLifespanKeywordId', 'validateKeyword'),
            array('volume', 'validateVolume'),
        );
    }

    public function validateUsername($attribute)
    {
        if (empty($this->username)) return;

        $portalDI = PortalDI::getInstance();
        $portalDI->setUsername($this->username);
        $portalDI->setPassword($this->password);
        $webnative = $portalDI->getHost();
        $userData = $portalDI->callPortal(PortalDI::ACTION_SHOWUSER_SETTINGS);

        if (!isset($userData['VENTURE_USERID'])) {
            $this->addError($attribute, "Username {$this->username} {$this->password} doesn't exist on webnative {$webnative}");
        }
    }

    public function validateKeyword($attribute)
    {
        if (empty($this->folderLifespanKeywordId)) return;

        $portalDI = PortalDI::getInstance();
        $portalDI->setUsername($this->username);
        $portalDI->setPassword($this->password);
        $webnative = $portalDI->getHost();

        $keywords = $portalDI->callPortal(PortalDI::ACTION_KEYWORDS);

        if (!isset($keywords[$this->folderLifespanKeywordId])) {
            $this->addError($attribute, "Keyword with ID {$this->username} doesn't exist on webnative {$webnative}");
        }
    }

    public function validateVolume($attribute)
    {
        if (empty($this->volume)) return;

        $portalDI = PortalDI::getInstance();
        $portalDI->setUsername($this->username);
        $portalDI->setPassword($this->password);
        $webnative = $portalDI->getHost();

        $result = $portalDI->callPortal(PortalDI::ACTION_FILEINFO, array(
            'action' => 'fileinfo',
            'path' => $this->volume,
            'showkywds' => 'false'
        ));

        if (!(isset($result['FILES_INFO']) && is_array($result['FILES_INFO']) && count($result['FILES_INFO']) > 0)) {
            $this->addError($attribute, "nTransit volume {$this->volume} doesn't exist on webnative {$webnative}");
        }
    }

    /**
     * Declares customized attribute labels.
     * If not declared here, an attribute would have a label that is
     * the same as its name with the first letter in upper case.
     */
    public function attributeLabels()
    {
        return array(
            'volume' => 'nTransit volume path',
            'actionName' => 'Trigger action name',
            'actionSettings' => 'Trigger action settings',
            'folderLifespanKeywordId' => 'Keyword ID',
            'folderLifespanKeyword' => 'Keyword name',
            'username' => 'Username',
            'password' => 'Password',
        );
    }
}
