<?php
/**
 * Created by PhpStorm.
 * User: konstantin
 * Date: 3/1/18
 * Time: 5:27 PM
 */

class ConfigParser
{

    const CONFIG_PATH = '/usr/napc/conf/ntransit';
    const PARTNER_LIST = 'partners.lst';
    const PARTNERS_FOLDER = 'partners';

    private $errors;
    private $data;

    public function parse()
    {

        require_once (dirname(__FILE__) . DIRECTORY_SEPARATOR . 'Yaml.php');

        /**
         * Check if nTransit 4 config folder exists
         */
        if (!file_exists(self::CONFIG_PATH)) {
            $this->errors[] = "nTransit 4 partners config folder '" . self::CONFIG_PATH . "' does not exists!";
            exit;
        }

        /**
         * Get partners list
         */
        $this->getPartners();

        echo json_encode(array('errors' => $this->errors, 'data' => $this->data));
    }

    /**
     * Gets partner list from partner config file
     */
    private function getPartners()
    {
        /**
         * Check if nTransit 4 config file exists
         */
        $partnersListPath = self::CONFIG_PATH . DIRECTORY_SEPARATOR . self::PARTNER_LIST;
        if (!file_exists($partnersListPath)) {
            $this->errors[] = "nTransit 4 partners config file '" . $partnersListPath .
                "' does not exists!";
            exit;
        }

        /**
         * Check if partner config file is readable
         */
        $partnersList = fopen($partnersListPath, "r");
        if (!$partnersList) {
            $this->errors[] = "Can not read nTransit 4 partners config file '" . $partnersListPath;
            exit;
        }

        /**
         * Parse partner folder and read partners config
         */
        while (!feof($partnersList)) {
            $partnerName = trim(fgets($partnersList));

            if ($partnerName === '') continue;

            /**
             * Check if partner config file exists
             */
            $partnerConfigFile = self::CONFIG_PATH . DIRECTORY_SEPARATOR . self::PARTNERS_FOLDER . DIRECTORY_SEPARATOR .
                $partnerName . '.conf';

            if (!file_exists($partnerConfigFile)) {
                $this->errors[] = 'Partner config file does not exists ' . $partnerConfigFile . '; ';
            } else {

                $this->parseConfigFile($partnerName, $partnerConfigFile);

            }
        }

        fclose($partnersList);
    }

    /**
     * @param string $partnerName
     * @param string $configFile
     */
    private function parseConfigFile($partnerName, $configFile)
    {
        $yaml  = new Yaml();
        $data = $yaml->load($configFile);

        foreach ($data as $key=>$val) {
            $this->data[$partnerName][$key] = $val;
        }
    }

}